const cvs = document.querySelector('canvas')
const ctx = cvs.getContext('2d')


function init() {
	/* 初始化画布大小 */
	cvs.width = window.innerWidth * devicePixelRatio;
	cvs.height = window.innerHeight * devicePixelRatio;
}
init();

function getRandom(min, max) {
	/* 随机生成辅助函数 */
	return Math.floor(Math.random() * (max + 1 - min));
}

// console.log(getRandom(1, 10));
/* 构造函数：随机生位置 绘制成点 */
class Point {
	constructor() {
		/* 设置圆的半径 */
		this.r = 3;
		/* 随机小球的XY */
		this.x = getRandom(0, cvs.width - this.r / 2);
		this.y = getRandom(0, cvs.height - this.r / 2);
		/* 随机小球的XY的速度 */
		this.xSpeed = getRandom(-100, 100);
		// console.log(this.xSpeed);
		this.ySpeed = getRandom(-100, 100);
		// console.log(this.ySpeed);
		/* 上次修改的时间 */
		this.lastDrawTime = null;
	}
	draw() {
		// 更新坐标
		if (this.lastDrawTime) {
			/* 计算新坐标 */
			const duration = (Date.now() - this.lastDrawTime) / 1000;
			const xDis = this.xSpeed * duration,
				yDis = this.ySpeed * duration;
			var x = this.x + xDis,
				y = this.y + yDis;
			if (x > cvs.width - this.r / 2) {
				/* 如果X大于屏幕宽度了，就反向。视觉效果像被反弹开了 */
				this.xSpeed = -this.xSpeed;
				x = cvs.width - this.r / 2;
			} else if (x < 0) {
				this.xSpeed = -this.xSpeed;
				x = this.r / 2;
			}
			console.log(y,cvs.height);
			if (y > cvs.height - this.r / 2) {
				/* Y同理 */
				console.log(y);
				this.ySpeed = -this.ySpeed;
				y = cvs.height - this.r / 2;
			} else if (y < 0) {
				this.ySpeed = -this.ySpeed;
				y = this.r / 2;
			}
			/* 在赋值之前先看看是不是大于屏幕了,到屏幕外边没意义了，然他翻转方向在计算 */
			this.x = x;
			this.y = y;
		}
		/* 设置绘制的样式 */
		ctx.beginPath();
		ctx.arc(this.x, this.y, this.r, 0, 2 * Math.PI);
		ctx.fillStyle = "rgba(200,200,200,1)";
		ctx.fill();
		/* 写入修改的时间 */
		this.lastDrawTime = Date.now();
	}
}
/* 图-构造函数：根据点来连线*/
class Graph {
	constructor(ponthNumber = 100, maxDis = 100) {
		/*创建数组ponthNumber个，然后分别执行构造函数Point来生成点 */
		this.points = new Array(ponthNumber).fill(0).map(() => new Point());
		this.maxDis = maxDis;
	}
	draw() {
		requestAnimationFrame(() => {
			this.draw();
		})
		/* 生成新图案之前先清掉之前的图案---动画的实现 */
		ctx.clearRect(0, 0, window.innerWidth, window.innerHeight);
		for (var i = 0; i < this.points.length; i++) {
			/* 拿到全部的点 */
			const p1 = this.points[i];
			p1.draw();
			/* 利用拿到的点来绘制线 */
			for (var j = i + 1; j < this.points.length; j++) {
				const p2 = this.points[j];
				/* 计算两点的距离，根据勾股定理：D的平方= x1-x2的平方 + y1-y2的平方 */
				const d = Math.sqrt((p1.x - p2.x) ** 2 + (p1.y - p2.y) ** 2);
				if (d > this.maxDis) {
					/* 如果距离过大，那就不绘制了 */
					continue;
				}
				/* 线的样式 */
				ctx.beginPath();
				ctx.moveTo(p1.x, p1.y);
				ctx.lineTo(p2.x, p2.y);
				ctx.closePath();
				ctx.strokeStyle = `rgba(200,200,200,${1-d/this.maxDis})`;
				ctx.stroke();
			}
		}
	}
}
/* 使用构造函数来绘制图像 */
const g = new Graph()
g.draw();




// const p1 = new Point();
// const p2 = new Point();
// p1.draw();
// p2.draw();


// for (var i = 0; i < 100; i++) {

// }

// ctx.beginPath();
// ctx.moveTo(100, 50);
// ctx.lineTo(200, 100);
// // ctx.lineTo(300,300)
// ctx.strokeStyle = "#fff";
// // ctx.fillStyle = "#fff";
// // ctx.closePath();
// ctx.stroke();
// // ctx.fill();


// ctx.beginPath();
// // ctx.moveTo(100,50);
// ctx.arc(100, 50, 6, 0, 2 * Math.PI);
// ctx.fillStyle = "#fff";
// ctx.fill();


// ctx.beginPath();
// // ctx.moveTo(100,50);
// ctx.arc(200, 100, 6, 0, 2 * Math.PI);
// ctx.fillStyle = "#fff";
// ctx.fill();